<img src="https://raw.githubusercontent.com/jaedb/iris/master/src/assets/logo.png" width="256" />

Iris (formerly known as Spotmop) is a Mopidy HTTP client that utilizes Spotify to create an interactive, user-friendly and collaborative music interface. Built and maintained by James Barnsley.

[![npm](https://img.shields.io/npm/v/mopidy-iris.svg?style=flat-square)]()
![badge](https://img.shields.io/pypi/v/mopidy-iris.svg?style=flat-square)
![badge](https://img.shields.io/badge/unique_monthly_users-4,000+-brightgreen.svg?style=flat-square)
[![badge](https://img.shields.io/badge/donate-paypal-blue.svg?style=flat-square)](https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=james%40barnsley%2enz&lc=NZ&item_name=James%20Barnsley&currency_code=USD&bn=PP%2dDonationsBF%3abtn_donate_LG%2egif%3aNonHosted)

Features
--------

* Full web-based interface controls for Mopidy
* Integrated with Spotify and LastFM APIs for high-quality artwork and extra info
* Support for any Mopidy backend
* Improved support for local libraries using SQLite extension
* Browse and manage your playlists, along with top tracks, new releases and genre browser
* Discover new and related music, powered by Spotify

![Overview](https://raw.githubusercontent.com/jaedb/iris/master/screenshot.jpg)


Requirements
--------

* Mopidy
* Mopidy-Spotify (recommended, not required)
* Mopidy-Local-Sqlite (recommended, not required)

Getting started
-------

* [Installation](https://github.com/jaedb/Iris/wiki/Getting-started#installing)
* [Debugging](https://github.com/jaedb/Iris/wiki/Advanced#debugging)
* [Issues and requests](https://github.com/jaedb/Iris/wiki/Support#before-you-log-an-issue)
* [Changelog](https://github.com/jaedb/iris/releases)

